aboutsummaryrefslogtreecommitdiff
path: root/src/mainboard/clevo
diff options
context:
space:
mode:
authorNicholas Sudsgaard <devel+coreboot@nsudsgaard.com>2024-02-22 13:33:15 +0900
committerFelix Singer <service+coreboot-gerrit@felixsinger.de>2024-02-29 03:12:43 +0000
commit4a62b8a5997873229f5342bffdee3e6b21772b06 (patch)
treeec21dd1c20bf0a935b8fd82352cb4fc84c6f9b99 /src/mainboard/clevo
parent9620b3d152e0c939d06b900aa65dba3f26ebe2e2 (diff)
include/device: Merge enums from azalia_device.h and azalia.h
We were keeping 2 copies of the same thing (albeit there were some slight differences). As azalia_device.h is used much more in the codebase this was kept as the base and then some of the nice features of azalia.h were incorporated. The significant changes are: - All enum names now use the `AZALIA_` prefix. This also drops the AzaliaPinConfiguration enum as it was never used since added in 2013. Change-Id: Ie874b083a18963679981a9cd2b25d123890d628e Signed-off-by: Nicholas Sudsgaard <devel+coreboot@nsudsgaard.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/80695 Reviewed-by: Nico Huber <nico.h@gmx.de> Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Felix Singer <service+coreboot-gerrit@felixsinger.de> Reviewed-by: Michael Niewöhner <foss@mniewoehner.de>
Diffstat (limited to 'src/mainboard/clevo')
-rw-r--r--src/mainboard/clevo/tgl-u/variants/l140mu/hda_verb.c70
1 files changed, 35 insertions, 35 deletions
diff --git a/src/mainboard/clevo/tgl-u/variants/l140mu/hda_verb.c b/src/mainboard/clevo/tgl-u/variants/l140mu/hda_verb.c
index 0ff24a2c79..2e1a5799d7 100644
--- a/src/mainboard/clevo/tgl-u/variants/l140mu/hda_verb.c
+++ b/src/mainboard/clevo/tgl-u/variants/l140mu/hda_verb.c
@@ -12,61 +12,61 @@ const u32 cim_verb_data[] = {
/* Microphone (display lid), vendor value: 0x90a60130 */
AZALIA_PIN_CFG(0, 0x12, AZALIA_PIN_DESC(
- INTEGRATED,
- LOCATION_OTHER, /* vendor: SEPARATE_CHASSIS */
- SPECIAL7, /* lid, vendor: NA */
- MIC_IN,
- OTHER_DIGITAL,
- COLOR_UNKNOWN,
- NO_JACK_PRESENCE_DETECT,
+ AZALIA_INTEGRATED,
+ AZALIA_LOCATION_OTHER, /* vendor: AZALIA_SEPARATE_CHASSIS */
+ AZALIA_SPECIAL7, /* lid, vendor: AZALIA_GEOLOCATION_NA*/
+ AZALIA_MIC_IN,
+ AZALIA_OTHER_DIGITAL,
+ AZALIA_COLOR_UNKNOWN,
+ AZALIA_NO_JACK_PRESENCE_DETECT,
3, 0)
),
/* Integrated speakers, vendor value: 0x90170110 */
AZALIA_PIN_CFG(0, 0x14, AZALIA_PIN_DESC(
- INTEGRATED,
- LOCATION_OTHER, /* vendor: SEPARATE_CHASSIS */
- BOTTOM, /* vendor: NA */
- SPEAKER,
- OTHER_ANALOG,
- COLOR_UNKNOWN,
- NO_JACK_PRESENCE_DETECT,
+ AZALIA_INTEGRATED,
+ AZALIA_LOCATION_OTHER, /* vendor: AZALIA_SEPARATE_CHASSIS */
+ AZALIA_BOTTOM, /* vendor: AZALIA_GEOLOCATION_NA*/
+ AZALIA_SPEAKER,
+ AZALIA_OTHER_ANALOG,
+ AZALIA_COLOR_UNKNOWN,
+ AZALIA_NO_JACK_PRESENCE_DETECT,
1, 0)
),
/* Headphones, vendor value: 0x02211020 */
AZALIA_PIN_CFG(0, 0x15, AZALIA_PIN_DESC(
- JACK,
- EXTERNAL_PRIMARY_CHASSIS,
- RIGHT, /* vendor: FRONT */
- HP_OUT,
- STEREO_MONO_1_8,
- BLACK,
- JACK_PRESENCE_DETECT,
+ AZALIA_JACK,
+ AZALIA_EXTERNAL_PRIMARY_CHASSIS,
+ AZALIA_RIGHT, /* vendor: AZALIA_FRONT */
+ AZALIA_HP_OUT,
+ AZALIA_STEREO_MONO_1_8,
+ AZALIA_BLACK,
+ AZALIA_JACK_PRESENCE_DETECT,
2, 0)
),
/* ext. Microphone, vendor value: 0x411111f0, linux override: 0x01a1913c */
AZALIA_PIN_CFG(0, 0x1a, AZALIA_PIN_DESC(
- JACK,
- EXTERNAL_PRIMARY_CHASSIS,
- RIGHT, /* vendor: REAR */
- MIC_IN,
- STEREO_MONO_1_8,
- BLACK, /* vendor: PINK */
- NO_JACK_PRESENCE_DETECT,
+ AZALIA_JACK,
+ AZALIA_EXTERNAL_PRIMARY_CHASSIS,
+ AZALIA_RIGHT, /* vendor: AZALIA_REAR */
+ AZALIA_MIC_IN,
+ AZALIA_STEREO_MONO_1_8,
+ AZALIA_BLACK, /* vendor: AZALIA_PINK */
+ AZALIA_NO_JACK_PRESENCE_DETECT,
3, 12)
),
/* PCBEEP, vendor value: 0x41748245 */
AZALIA_PIN_CFG(0, 0x1d, AZALIA_PIN_DESC(
- INTEGRATED, /* vendor: NC */
- INTERNAL, /* vendor: EXTERNAL_PRIMARY_CHASSIS */
- NA, /* vendor: REAR */
- DEVICE_OTHER, /* vendor: MODEM_HANDSET_SIDE */
- OTHER_ANALOG, /* vendor: RCA */
- COLOR_UNKNOWN, /* vendor: PURPLE */
- NO_JACK_PRESENCE_DETECT, /* vendor: 2 */
+ AZALIA_INTEGRATED, /* vendor: AZALIA_NC */
+ AZALIA_INTERNAL, /* vendor: AZALIA_EXTERNAL_PRIMARY_CHASSIS */
+ AZALIA_GEOLOCATION_NA, /* vendor: AZALIA_REAR */
+ AZALIA_DEVICE_OTHER, /* vendor: AZALIA_MODEM_HANDSET_SIDE */
+ AZALIA_OTHER_ANALOG, /* vendor: AZALIA_RCA */
+ AZALIA_COLOR_UNKNOWN, /* vendor: AZALIA_PURPLE */
+ AZALIA_NO_JACK_PRESENCE_DETECT, /* vendor: 2 */
4, 5)
),